# MapAttributesQuestionInput

A collection of input for the map attributes question. This contains both the user about whom we want to map attributes and the set of attributes we want to map. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**login_info** | [**MapAttributesQuestionLoginInfo**](MapAttributesQuestionLoginInfo.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


